Class: Telbe::ForwardMessageDescriptor

Inherits:
Object
  • Object
show all
Includes:
SimplifyApi
Defined in:
lib/telbe/bot.rb

Overview

chat_id Integer or String Yes Unique identifier for the target chat or username of the target channel (in the format @channelusername) from_chat_id Integer or String Yes Unique identifier for the chat where the original message was sent (or channel username in the format @channelusername) disable_notification Boolean Optional Sends the message silently. Users will receive a notification with no sound. message_id Integer Yes Message identifier in the chat specified in from_chat_id