Class: Telbe::InlineQuery

Inherits:
Object
  • Object
show all
Includes:
SimplifyApi
Defined in:
lib/telbe/inline.rb

Overview

id String Unique identifier for this query from User Sender location Location Optional. Sender location, only for bots that request user location query String Text of the query (up to 512 characters) offset String Offset of the results to be returned, can be controlled by the bot