Class: Telbe::InlineQueryResultAudio
- Inherits:
-
InlineQueryResult
- Object
- InlineQueryResult
- Telbe::InlineQueryResultAudio
- Defined in:
- lib/telbe/inline.rb
Overview
type String Type of the result, must be audio id String Unique identifier for this result, 1-64 bytes audio_url String A valid URL for the audio file title String Title caption String Optional. Caption, 0-1024 characters parse_mode String Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption. performer String Optional. Performer audio_duration Integer Optional. Audio duration in seconds reply_markup InlineKeyboardMarkup Optional. Inline keyboard attached to the message input_message_content InputMessageContent Optional. Content of the message to be sent instead of the audio