Class: Telbe::InlineQueryResultCachedAudio

Inherits:
InlineQueryResult show all
Defined in:
lib/telbe/inline.rb

Overview

type String Type of the result, must be audio id String Unique identifier for this result, 1-64 bytes audio_file_id String A valid file identifier for the audio file caption String Optional. Caption, 0-1024 characters parse_mode String Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption. reply_markup InlineKeyboardMarkup Optional. Inline keyboard attached to the message input_message_content InputMessageContent Optional. Content of the message to be sent instead of the audio

Method Summary

Methods inherited from InlineQueryResult

inherited