Class: Telbe::InlineQueryResultCachedDocument

Inherits:
InlineQueryResult show all
Defined in:
lib/telbe/inline.rb

Overview

type String Type of the result, must be document id String Unique identifier for this result, 1-64 bytes title String Title for the result document_file_id String A valid file identifier for the file description String Optional. Short description of the result caption String Optional. Caption of the document to be sent, 0-1024 characters parse_mode String Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption. reply_markup InlineKeyboardMarkup Optional. Inline keyboard attached to the message input_message_content InputMessageContent Optional. Content of the message to be sent instead of the file

Method Summary

Methods inherited from InlineQueryResult

inherited