Class: Telbe::InlineQueryResultDocument
- Inherits:
-
InlineQueryResult
- Object
- InlineQueryResult
- Telbe::InlineQueryResultDocument
- Defined in:
- lib/telbe/inline.rb
Overview
type String Type of the result, must be document id String Unique identifier for this result, 1-64 bytes title String Title for the result caption String Optional. Caption of the document to be sent, 0-1024 characters parse_mode String Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption. document_url String A valid URL for the file mime_type String Mime type of the content of the file, either “application/pdf” or “application/zip”description String Optional. Short description of the result reply_markup InlineKeyboardMarkup Optional. Inline keyboard attached to the message input_message_content InputMessageContent Optional. Content of the message to be sent instead of the file thumb_url String Optional. URL of the thumbnail (jpeg only) for the file thumb_width Integer Optional. Thumbnail width thumb_height Integer Optional. Thumbnail height