Class: Telbe::InlineQueryResultLocation
- Inherits:
-
InlineQueryResult
- Object
- InlineQueryResult
- Telbe::InlineQueryResultLocation
- Defined in:
- lib/telbe/inline.rb
Overview
type String Type of the result, must be location id String Unique identifier for this result, 1-64 Bytes latitude Float number Location latitude in degrees longitude Float number Location longitude in degrees title String Location title live_period Integer Optional. Period in seconds for which the location can be updated, should be between 60 and 86400. reply_markup InlineKeyboardMarkup Optional. Inline keyboard attached to the message input_message_content InputMessageContent Optional. Content of the message to be sent instead of the location thumb_url String Optional. Url of the thumbnail for the result thumb_width Integer Optional. Thumbnail width thumb_height Integer Optional. Thumbnail height