Class: Telbe::InlineQueryResultMpeg4Gif
- Inherits:
-
InlineQueryResult
- Object
- InlineQueryResult
- Telbe::InlineQueryResultMpeg4Gif
- Defined in:
- lib/telbe/inline.rb
Overview
type String Type of the result, must be mpeg4_gif id String Unique identifier for this result, 1-64 bytes mpeg4_url String A valid URL for the MP4 file. File size must not exceed 1MB mpeg4_width Integer Optional. Video width mpeg4_height Integer Optional. Video height mpeg4_duration Integer Optional. Video duration thumb_url String URL of the static thumbnail (jpeg or gif) for the result title String Optional. Title for the result caption String Optional. Caption of the MPEG-4 file to be sent, 0-1024 characters parse_mode String Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption. reply_markup InlineKeyboardMarkup Optional. Inline keyboard attached to the message input_message_content InputMessageContent Optional. Content of the message to be sent instead of the video animation