Class: Telbe::InputMessageContent

Inherits:
Object
  • Object
show all
Includes:
SimplifyApi
Defined in:
lib/telbe/inline.rb

Overview

message_text String Text of the message to be sent, 1-4096 characters parse_mode String Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in your bot’s message. disable_web_page_preview Boolean Optional. Disables link previews for links in the sent message