Class: Telbe::InputVenueMessageContent
- Inherits:
-
Object
- Object
- Telbe::InputVenueMessageContent
- Includes:
- SimplifyApi
- Defined in:
- lib/telbe/inline.rb
Overview
latitude Float Latitude of the venue in degrees longitude Float Longitude of the venue in degrees title String Name of the venue address String Address of the venue foursquare_id String Optional. Foursquare identifier of the venue, if known foursquare_type String Optional. Foursquare type of the venue, if known. (For example, “arts_entertainment/default”, “arts_entertainment/aquarium” or “food/icecream”.)