Class: Telbe::PinChatMessageDescriptor
- Inherits:
-
Object
- Object
- Telbe::PinChatMessageDescriptor
- Includes:
- SimplifyApi
- Defined in:
- lib/telbe/chat.rb
Overview
chat_id Integer or String Yes Unique identifier for the target chat or username of the target channel (in the format @channelusername) message_id Integer Yes Identifier of a message to pin disable_notification Boolean Optional Pass True, if it is not necessary to send a notification to all chat members about the new pinned message. Notifications are always disabled in channels.