Class: Telbe::Poll
Overview
id String Unique poll identifier question String Poll question, 1-255 characters options Array of PollOption List of poll options is_closed Boolean True, if the poll is closed
id String Unique poll identifier question String Poll question, 1-255 characters options Array of PollOption List of poll options is_closed Boolean True, if the poll is closed