Class: Telbe::SendStickerDescriptor
- Inherits:
-
Object
- Object
- Telbe::SendStickerDescriptor
- Includes:
- SimplifyApi
- Defined in:
- lib/telbe/sticker.rb
Overview
chat_id Integer or String Yes Unique identifier for the target chat or username of the target channel (in the format @channelusername) sticker InputFile or String Yes Sticker to send. Pass a file_id as String to send a file that exists on the Telegram servers (recommended), pass an HTTP URL as a String for Telegram to get a .webp file from the Internet, or upload a new one using multipart/form-data. More info on Sending Files »disable_notification Boolean Optional Sends the message silently. Users will receive a notification with no sound. reply_to_message_id Integer Optional If the message is a reply, ID of the original message reply_markup InlineKeyboardMarkup or ReplyKeyboardMarkup or ReplyKeyboardRemove or ForceReply Optional Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.