Class: Telbe::SendVideoDescriptor

Inherits:
MediaDescriptor show all
Defined in:
lib/telbe/media.rb

Overview

chat_id Integer or String Yes Unique identifier for the target chat or username of the target channel (in the format @channelusername) video InputFile or String Yes Video to send. Pass a file_id as String to send a video that exists on the Telegram servers (recommended), pass an HTTP URL as a String for Telegram to get a video from the Internet, or upload a new video using multipart/form-data. More info on Sending Files »duration Integer Optional Duration of sent video in seconds width Integer Optional Video width height Integer Optional Video height thumb InputFile or String Optional Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail‘s width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »caption String Optional Video caption (may also be used when resending videos by file_id), 0-1024 characters parse_mode String Optional Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption. supports_streaming Boolean Optional Pass True, if the uploaded video is suitable for streaming disable_notification Boolean Optional Sends the message silently. Users will receive a notification with no sound. reply_to_message_id Integer Optional If the message is a reply, ID of the original message reply_markup InlineKeyboardMarkup or ReplyKeyboardMarkup or ReplyKeyboardRemove or ForceReply Opt

Method Summary

Methods inherited from MediaDescriptor

inherited

Methods inherited from Descriptor

inherited