Class: Telbe::SetChatPhotoDescriptor
- Inherits:
-
Object
- Object
- Telbe::SetChatPhotoDescriptor
- Includes:
- SimplifyApi
- Defined in:
- lib/telbe/chat.rb
Overview
chat_id Integer or String Yes Unique identifier for the target chat or username of the target channel (in the format @channelusername) photo InputFile Yes New chat photo, uploaded using multipart/form-data