Class: Telbe::SetStickerPositionInSetDescriptor

Inherits:
Object
  • Object
show all
Includes:
SimplifyApi
Defined in:
lib/telbe/sticker.rb

Overview

sticker String Yes File identifier of the sticker position Integer Yes New sticker position in the set, zero-based