Class: Telbe::User

Inherits:
Object
  • Object
show all
Includes:
SimplifyApi
Defined in:
lib/telbe/user.rb

Overview

id Integer Unique identifier for this user or bot is_bot Boolean True, if this user is a bot first_name String User‘s or bot’s first name last_name String Optional. User‘s or bot’s last name username String Optional. User‘s or bot’s username language_code String Optional. IETF language tag of the user’s language