Class: Telbe::EditMessageLiveLocationDescriptor
- Inherits:
-
Object
- Object
- Telbe::EditMessageLiveLocationDescriptor
- Includes:
- SimplifyApi
- Defined in:
- lib/telbe/location.rb
Overview
chat_id Integer or String Optional Required if inline_message_id is not specified. Unique identifier for the target chat or username of the target channel (in the format @channelusername) message_id Integer Optional Required if inline_message_id is not specified. Identifier of the message to edit inline_message_id String Optional Required if chat_id and message_id are not specified. Identifier of the inline message latitude Float number Yes Latitude of new location longitude Float number Yes Longitude of new location reply_markup InlineKeyboardMarkup Optional A JSON-serialized object for a new inline keyboard.