Class: Telbe::InlineQueryResultCachedSticker
- Inherits:
-
InlineQueryResult
- Object
- InlineQueryResult
- Telbe::InlineQueryResultCachedSticker
- Defined in:
- lib/telbe/inline.rb
Overview
type String Type of the result, must be sticker id String Unique identifier for this result, 1-64 bytes sticker_file_id String A valid file identifier of the sticker reply_markup InlineKeyboardMarkup Optional. Inline keyboard attached to the message input_message_content InputMessageContent Optional. Content of the message to be sent instead of the sticker