Class: Telbe::InlineQueryResultGame

Inherits:
InlineQueryResult show all
Defined in:
lib/telbe/inline.rb

Overview

type String Type of the result, must be game id String Unique identifier for this result, 1-64 bytes game_short_name String Short name of the game reply_markup InlineKeyboardMarkup Optional. Inline keyboard attached to the message

Method Summary

Methods inherited from InlineQueryResult

inherited