Class: Telbe::KeyboardButton
- Inherits:
-
Object
- Object
- Telbe::KeyboardButton
- Includes:
- SimplifyApi
- Defined in:
- lib/telbe/keyboard.rb
Overview
text String Text of the button. If none of the optional fields are used, it will be sent as a message when the button is pressed request_contact Boolean Optional. If True, the user’s phone number will be sent as a contact when the button is pressed. Available in private chats only request_location Boolean Optional. If True, the user’s current location will be sent when the button is pressed. Available in private chats only