Class: Telbe::SetChatStickerSetDescriptor

Inherits:
Object
  • Object
show all
Includes:
SimplifyApi
Defined in:
lib/telbe/chat.rb

Overview

chat_id Integer or String Yes Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername) sticker_set_name String Yes Name of the sticker set to be set as the group sticker set