Class: Telbe::StopPollDescriptor
- Inherits:
-
Object
- Object
- Telbe::StopPollDescriptor
- Includes:
- SimplifyApi
- Defined in:
- lib/telbe/poll.rb
Overview
chat_id Integer or String Yes Unique identifier for the target chat or username of the target channel (in the format @channelusername) message_id Integer Yes Identifier of the original message with the poll reply_markup InlineKeyboardMarkup Optional A JSON-serialized object for a new message inline keyboard.